=========
nblast-rs
=========

Python bindings for nblast rust library.

* Free software: GPL3 license

Building
--------

If wheels are not available for your platform, they can be built locally if you have a `recent stable rust compiler <https://www.rust-lang.org/tools/install>`_.

::

    git clone https://github.com/clbarnes/nblast-rs
    cd nblast-rs/nblast-py
    pip install .
